==> kubernetes-model-1.0.13-sources.jar: io/fabric8/kubernetes/api/model/MetadataVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.HashMap;
import java.util.Map;
import java.util.List;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Visitable;

public class MetadataVolumeSourceBuilder extends MetadataVolumeSourceFluent<MetadataVolumeSourceBuilder> implements VisitableBuilder<MetadataVolumeSource,MetadataVolumeSourceBuilder>{

     MetadataVolumeSourceFluent<?> fluent;
public MetadataVolumeSourceBuilder(){
    this(new MetadataVolumeSource());
}
public MetadataVolumeSourceBuilder( MetadataVolumeSourceFluent<?> fluent ){
    this(fluent, new MetadataVolumeSource());
}
public MetadataVolumeSourceBuilder( MetadataVolumeSourceFluent<?> fluent , MetadataVolumeSource instance ){
    this.fluent = fluent; fluent.withItems(instance.getItems()); 
}
public MetadataVolumeSourceBuilder( MetadataVolumeSource instance ){
    this.fluent = this; this.withItems(instance.getItems()); 
}

public EditableMetadataVolumeSource build(){
    EditableMetadataVolumeSource buildable = new EditableMetadataVolumeSource(fluent.getItems());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
MetadataVolumeSourceBuilder that = (MetadataVolumeSourceBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.37-sources.jar: io/fabric8/kubernetes/api/model/MetadataVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.ArrayList;
import java.util.Map;
import java.util.HashMap;
import java.util.List;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Builder;

public class MetadataVolumeSourceBuilder extends MetadataVolumeSourceFluentImpl<MetadataVolumeSourceBuilder> implements VisitableBuilder<MetadataVolumeSource,MetadataVolumeSourceBuilder>{

     MetadataVolumeSourceFluent<?> fluent;
public MetadataVolumeSourceBuilder(){
    this(new MetadataVolumeSource());
}
public MetadataVolumeSourceBuilder( MetadataVolumeSourceFluent<?> fluent ){
    this(fluent, new MetadataVolumeSource());
}
public MetadataVolumeSourceBuilder( MetadataVolumeSourceFluent<?> fluent , MetadataVolumeSource instance ){
    this.fluent = fluent; fluent.withItems(instance.getItems()); 
}
public MetadataVolumeSourceBuilder( MetadataVolumeSource instance ){
    this.fluent = this; this.withItems(instance.getItems()); 
}

public EditableMetadataVolumeSource build(){
    EditableMetadataVolumeSource buildable = new EditableMetadataVolumeSource(fluent.getItems());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
MetadataVolumeSourceBuilder that = (MetadataVolumeSourceBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}
